use std::io;
use thiserror::Error;

#[derive(Error, Debug)]
pub enum ProcessError {
    #[error("IO error: {0}")]
    Io(#[from] io::Error),

    #[error("Path strip error: {0}")]
    StripPrefix(#[from] std::path::StripPrefixError),

    #[error("Directory processing error: {0}")]
    Processing(String),

    #[error("Logging error: {0}")]
    Log(#[from] LogError),
}

#[derive(Error, Debug)]
pub enum LogError {
    #[error("IO error: {0}")]
    Io(#[from] io::Error),

    #[error("Logger initialization error: {0}")]
    Init(String),

    #[error("Logger already initialized")]
    AlreadyInitialized,

    #[error("Lock poisoned: {0}")]
    LockPoisoned(String),
}

pub type Result<T> = std::result::Result<T, ProcessError>;
